<?php 

$lang['ln_lang'] = 'Язык';
$lang['ln_content'] = 'Содержание';
$lang['ln_document_type'] = 'Тип документа';
$lang['Enter resource id'] = 'Введите id ресурса';

$lang['btn_save'] = 'Сохранить';
$lang['btn_cancel'] = 'Закрыть текущую вкладку';
$lang['btn_close_other'] = 'Закрыть другие вкладки';

$lang['msg_saved'] = 'Данные успешно сохранены';
$lang['msg_fail'] = 'Ошибка сохранения данных';

$lang['Date not saved. Close current tab?'] = 'Данные не были сохранены. Закрыть вкладку?';

$lang['Folder'] = 'Каталог';
$lang['Page template'] = 'Шаблон страницы';
$lang['Page'] = 'Страница';
$lang['Resource'] = 'Ресурс';