<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_resmng'] = array(
    array(
        'version' => '0',
        'library' => 'resmng/migrations/resmng_upgrade_0',
    ),
    array(
        'version' => '1.0.7',
        'library' => 'resmng/migrations/resmng_upgrade_1_0_7',
    ),
    array(
        'version' => '1.0.8',
        'library' => 'resmng/migrations/resmng_upgrade_1_0_8',
    ),
    array(
        'version' => '1.0.12',
        'library' => 'resmng/migrations/resmng_upgrade_1_0_12',
    ),
);
