<ul class="connectedSortable sub-menu">
    {item}
    <li rel="set_{id_resource}" {sub_level}>
        <a href="#" title="{item_title}" class="tree_menu_item"><i class="{item_icon}"></i> <span class="item_name">{item_name}</span>{item_private}</a>
        {children}
    </li>
    {/item}
</ul>